@@ -1,7 +1,8 @@
-#!/usr/bin/env python
+__all__ = ['request', 'get', 'delete']
+
+
 import json
 import os
-import public
 import requests
 
 """
@@ -9,7 +10,6 @@ https://developer.github.com/v3/repos/hooks/
 """
 
 
-@public.add
 def request(method, url, data=None, **kwargs):
     """make request and return response"""
     token = os.environ["GITHUB_TOKEN"]
@@ -23,14 +23,12 @@ def request(method, url, data=None, **kwargs):
     return r
 
 
-@public.add
 def get(fullname):
     """return a list of repo webhooks data"""
     url = "https://api.github.com/repos/%s/hooks" % fullname
     return request("GET", url).json()
 
 
-@public.add
 def delete(fullname, hook_id):
     """delete repo webhook"""
     url = "https://api.github.com/repos/%s/hooks/%s" % (fullname, int(hook_id))
